﻿namespace Contracts
{
    /// <summary>
    /// Types of energy, based on ecology.
    /// </summary>
    /// <remarks>Helper for MEF Metadata: ExportMetadata attribute.</remarks>
    public enum EnergyTypes
    {
        /// <summary>
        /// Kyoto friendly.
        /// </summary>
        Renewable,

        /// <summary>
        /// Not everybody agrees.
        /// </summary>
        Questionable,

        /// <summary>
        /// Definitely Kyoto unfriendly.
        /// </summary>
        GloballyWarming
    }

    /// <summary>
    /// Power Supplier Metadata.
    /// </summary>
    /// <remarks>Helper for MEF Metadata: Lazy(T, TMetadata)</remarks>
    public interface IPowerSupplierMetadata
    {
        /// <summary>
        /// Gets the Energy Type.
        /// </summary>
        EnergyTypes EnergyType { get; }
    }

    /// <summary>
    /// Power Supplier.
    /// </summary>
    /// <remarks>Helper for MEF Metadata: ExportMetadata attribute.</remarks>
    public class PowerSupplier
    {
        /// <summary>
        /// Energy Type.
        /// </summary>
        public const string EnergyType = "EnergyType";
    }
}
