﻿namespace My
{
    using System.ComponentModel.Composition; // MEF
    using Contracts;

    /// <summary>
    /// My laptop.
    /// </summary>
    /// <remarks>
    /// Plays the role of 'Export Part' in the 
    /// Management Extensibility Framework.
    /// </remarks>
    [Export(typeof(IPowerConsumer))]
    public class Laptop : IPowerConsumer
    {
        /// <summary>
        /// The supplier of energy.
        /// </summary>
        /// <remarks>
        /// Plays the role of 'Import Part' in the 
        /// Management Extensibility Framework.
        /// </remarks>
        [Import]
        public IPowerSupplier PowerSupplier { get; set; }

        /// <summary>
        /// What the consumer does with the electricity.
        /// </summary>
        /// <returns>Just a message.</returns>
        public string Start()
        {
            return string.Format(
                "{0} {1} is writing blog entries thanks to the {2} from {3} {4}.",
                this.GetType().Namespace,
                this.GetType().Name,
                this.PowerSupplier.EnergySource,
                this.PowerSupplier.GetType().Namespace,
                this.PowerSupplier.GetType().Name);
        }
    }
}
