﻿namespace U2UConsult.MEF.Sample
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel.Composition; // MEF
    using System.ComponentModel.Composition.Hosting; // MEF
    using System.Linq;
    using System.Text;
    using Contracts; // Power Supplier Contract 

    /// <summary>
    /// Responsible for the transmission of electricity.
    /// </summary>
    /// <remarks>
    /// Plays the role of 'Container' in the MEF.
    /// Illustrates ImportMany.
    /// </remarks>
    public class DistributionOperator
    {
        /// <summary>
        /// Initializes a new instance of the DistributionOperator class.
        /// </summary>
        public DistributionOperator()
        {
            // Load parts from catalog.
            var catalog = new DirectoryCatalog(@"../../MultiImport");
            var container = new CompositionContainer(catalog);
            container.ComposeParts(this);
        }

        /// <summary>
        /// Gets or sets the list of electricity suppliers.
        /// </summary>
        [ImportMany]
        public IEnumerable<IPowerSupplier> Suppliers { get; set; }

        /// <summary>
        /// Gets or sets the list of Kyoto-friendly electricity suppliers.
        /// </summary>
        [ImportMany]
        private IEnumerable<Lazy<IPowerSupplier, IPowerSupplierMetadata>> SuppliersWithMetadata { get; set; }

        /// <summary>
        /// Returns the Kyoto-friendly electricity suppliers.
        /// </summary>
        /// <returns>A list of IPowerSupplier instances.</returns>
        public IEnumerable<IPowerSupplier> KyotoFriendlySuppliers()
        {
            var query = from s in this.SuppliersWithMetadata
                        where s.Metadata.EnergyType.Equals(EnergyTypes.Renewable)
                        select s.Value;
            return query;
        }
    }
}
