﻿namespace U2UConsult.MEF.Sample
{
    using System.ComponentModel.Composition; // MEF
    using System.ComponentModel.Composition.Hosting; // MEF
    using Contracts; // Power Contract

    /// <summary>
    /// Finds a consumer and a supplier, and connects them.
    /// </summary>
    /// <remarks>
    /// Plays the role of 'Container' in the MEF.
    /// Illustrates dynamic object graph loading.
    /// </remarks>
    public class PowerPlug
    {
        /// <summary>
        /// Initializes a new instance of the PowerPlug class.
        /// </summary>
        public PowerPlug()
        {
            // Load parts from catalog.
            var catalog = new DirectoryCatalog(@"../../Hooked");
            var container = new CompositionContainer(catalog);
            container.ComposeParts(this);
        }

        /// <summary>
        /// Gets or sets the consumer of electricity.
        /// </summary>
        [Import]
        public IPowerConsumer Consumer { get; set; }

        /// <summary>
        /// Gets or sets the supplier of electricity.
        /// </summary>
        /// <remarks>The demo also works without this property.</remarks>
        [Import]
        public IPowerSupplier Supplier { get; set; }
    }
}
